Welcome to RLite's documentation!
=================================

RLite is a lightweight and efficient framework for training and inference of large language models. It is designed to be simple, flexible, and scalable. To minimize the learning overhead, RLite is built on top of PyTorch and HuggingFace Transformers, keeping as similar interfaces as possible.

Contents
--------

.. toctree::

   quick_start
   introduction
   inference
   train
   resman
   debug
   faq
